<?php

/**
 * @file
 * Migrate comment given in xml format.
 */

/**
 * Implementation of WordPressMigration, for comment.
 */

class WordPressCommentMigration extends XMLMigration {

  public $contenttype = 'post';
  public $dependencies = array('WordPressPost');
  public $nidsourcemigration = 'WordPressPost';

  public $description = 'Comments for Posts';

  public $xmlfolder = 'migrate/inbox/comments_xml';

  public $defaultfilterformat = 2;
  public $defaultuid = 0;

  public $fields = array(
    'comment_id' => 'Comment ID',
    'user_name' => 'Username for Commenter',
    'name' => 'NN display name for Commenter',
    'email' => 'Commenter\'s Email',
    'date' => 'Comment timestamp',
    'article_id' => 'for article to which comment is attached',
    'text' => 'The comment itself',
    'uid' => 'Drupal uid',
    'status' => 'Comment status',
  );

  /**
   * Modify source row by using data from xml.
   */
  public function prepareRow($row) {
    foreach ($this->fields as $field => $desc) {
      $row->{$field} = (string) $row->xml->comment[$field];
    }
    $row->text = (string) $row->xml->comment;
    $uid = db_result(db_query("select uid from {users} where name = '%s'", $row->user_name));
    if ($uid) {
      $row->uid = $uid;
    }
    if ($row->status == 1) {
      $row->status = 0;
    }
    elseif ($row->status == 'spam') {
      $row->status = 1;
    }
  }

  /**
   * Custom function to set up source and destination mapping.
   */
  public function setupmap() {

    // 0 == published.
    $this->addFieldMapping('status', 'status');
    $this->addFieldMapping('format')
      ->defaultValue($this->defaultfilterformat);
    $this->addFieldMapping('uid', 'uid')
      ->defaultValue($this->defaultuid);
    $this->addFieldMapping('nid', 'article_id')
      ->sourceMigration($this->nidsourcemigration);
    $this->addFieldMapping('comment', 'text');
    $this->addFieldMapping('timestamp', 'date');
    $this->addFieldMapping('name', 'name');
    $this->addFieldMapping('mail', 'email');
  }

  /**
   * Set it up : Initialisation.
   */
  public function __construct() {
    parent::__construct();

    $xml_path = file_directory_path() . '/' . $this->xmlfolder;

    $this->map = new MigrateSQLMap(
      $this->machineName,
      array(
        'comment_id' => array(
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => TRUE,
        ),
      ),
      MigrateDestinationComment::getKeySchema()
    );
    $item_url = $xml_path . '/:id.xml';
    $this->source = new MigrateSourceList(new WordpressMigrateListFiles($xml_path),
      new MigrateItemXML($item_url), $this->fields);

    $this->destination = new MigrateDestinationComment($this->contenttype);
    $this->setupmap();
  }
}
