<?php

/**
 * @file
 * Migrate tag given in csv format.
 */

/**
 * Implementation of WordPressMigration, for tag.
 */
class WordPressTagMigration extends Migration {
  // Destination vocabulary name.
  public $file = 'wordpress/tag.csv';
  public $vocab = '';
  /**
   * Set it up : Initialisation.
   */
  public function __construct() {
    parent::__construct();

    $vid = variable_get('wp_migrate_category_vocabulary', '');
    $vocabulary = taxonomy_vocabulary_load($vid);
    $this->vocab = $vocabulary->name;
    $this->description = "Migrate Wordpress tags (wpcr_term_taxonomy) from a CSV file, keeping tree structure";
    $this->map = new MigrateSQLMap(
      $this->machineName,
      array(
        'termid' => array(
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => TRUE,
          'description' => 'Term ID',
        ),
      ),
      MigrateDestinationTerm::getKeySchema()
    );
    $fields = array(
      array('termid', 'Term ID'),
      array('name', 'Term Name'),
      array('parentid', 'Parent Term ID'),
    );
    $this->source = new MigrateSourceCSV(file_directory_path() . '/' . $this->file, $fields);
    $this->destination = new MigrateDestinationTerm($this->vocab);

    $this->addFieldMapping('name', 'name');
    $this->addFieldMapping('parent', 'parentid')
      ->sourceMigration($this->machineName);
  }

  /**
   * In case a term's parent hasn't been created yet,make a stub.
   */
  protected function createStub($migration) {
    $vid = db_select('vocabulary', 'v')
      ->fields('v', array('vid'))
      ->condition('name', $this->vocab)
      ->execute()
      ->fetchField();

    $term = array(
      'vid' => $vid,
      'name' => 'Stub');

    taxonomy_save_term($term);

    if ($term['tid']) {
      return array($term['tid']);
    }
    else {
      return FALSE;
    }
  }
}
