<?php
/**
 * @file
 * Migrate user given in .csv format.
 */

/**
 * Implementation of WordPressMigration, for user.
 */
class WordPressUserMigration extends Migration {
  public $file = 'wordpress/user.csv';
  /**
   * Set it up : Initialisation.
   */
  public function __construct() {
    parent::__construct();
    $this->description = "Migrate Users (wpcr_users) from a CSV file";

    $this->map = new MigrateSQLMap(
      $this->machineName,
      array(
        'username' => array(
          'type' => 'varchar',
          'length' => 60,
          'not null' => TRUE,
          'description' => 'User ID',
        ),
      ),
      MigrateDestinationUser::getKeySchema()
    );
    $additional_fields = array();

    $this->source = new MigrateSourceCSV(file_directory_path() . '/' . $this->file,
      array(),
      array('header_rows' => 1),
      $additional_fields
    );
    $this->destination = new MigrateDestinationUser();

    $this->addFieldMapping('name', 'username')
      ->dedupe('users', 'name');
    $this->addFieldMapping('mail', 'email');
    $this->addFieldMapping('roles')
      ->defaultValue(DRUPAL_AUTHENTICATED_RID);
  }

  /**
   * Modify user object and add pass.
   */
  public function prepare($account, $row) {
    // If there is no password, set a random one.
    if (!$account->pass) {
      $account->pass = user_password();
    }
  }

}
